==> QuickAMS-1.0.21-sources.jar: static/load/loadListBlock.js <==
function getMatchBlock(block){
    //匹配公共部分
    for(let prop in userBlockMap){
        let tokens = prop.split("|");
        let projectName = tokens[0];
        let daoName = tokens[1];
        let tableName = tokens[2];

        if(projectName===block["projectName"]&&daoName==="common"&&tableName===block["tableName"]){
            return userBlockMap[prop];
        }
    }
    //完全匹配
    for(let prop in userBlockMap){
        let tokens = prop.split("|");
        let projectName = tokens[0];
        let daoName = tokens[1];
        let tableName = tokens[2];

        if(projectName===block["projectName"]&&daoName===block["daoName"]&&tableName===block["tableName"]){
            return userBlockMap[prop];
        }
    }
}

function loadBlock(block){
    let matchBlock = getMatchBlock(block);
    loadResource(block, matchBlock);
    loadListBlock(block, matchBlock);
}

function loadResource(block, matchBlock) {
    let resourceBlock = {
        "key": block["id"],
        "api": {
            "prefix": "/ams/api/"+block["projectName"]+"/"+block["daoName"]+"/"+block["tableName"],
            "list": "/list",
            "create": "/create",
            "update": "/update",
            "delete": "/delete"
        },
        "fields": block["resourceFields"]
    };
    if(null!=matchBlock&&matchBlock.hasOwnProperty("resource")){
        mergeBlock(matchBlock["resource"], resourceBlock);
        delete matchBlock["resource"];
    }
    ams.blockConfig["resourceBlockMap"][block["uniqueKey"]] = resourceBlock;
    ams.resource(block["resourceName"], resourceBlock);
}

function loadListBlock(block, matchBlock){
    let listBlock = {
        "resource": block["resourceName"],
        "type": "list",
        "ctx": "view",
        "props": {
            "empty-text": "暂无记录",
        },
        "sorts": {},
        "expand": {},
        "options": {
            "multipleSelect": true,
        },
        "operations":{

        },
        "actions": {
            initialCondition(){
                let searchFields = Object.keys(this["fields"]);
                for(let i=0;i<searchFields.length;i++){
                    let value = ams.utils.getQueryString(searchFields[i]);
                    if(null!=value&&value!==""){
                        value = decodeURIComponent(value);
                        this["data"]["searchs"][searchFields[i]] = value;
                    }
                }
                if(block["initList"]){
                    this.callAction("list:1");
                }
            },
            copyRow(params) {
                let row = params.$prevReturn;
                setClipBoard(JSON.stringify(row));
                this.$message.success("行数据已复制到剪贴板");
            },
            multipleDelete(params){
                let idFieldName = block["id"];
                let ids = ams.utils.getIdsString(params, idFieldName);
                let data = {};
                data[idFieldName] = "in:"+ids;

                return ams.utils.sendRequest(this, {
                    "method": "POST",
                    "url": "/delete",
                    "data": data,
                    "contentType": "form"
                }, "删除记录完成!");
            }
        }
    };
    listBlock["events"] = {
        "init": "initialCondition"
    };
    listBlock["operations"] = block["operationFields"];

    for(let prop in block["resourceFields"]){
        listBlock["sorts"][prop] = true;
        listBlock["expand"][prop] = true;
        if(prop==="id"){
            listBlock["data"] = {
                "searchs": {
                    "sortField": "id",
                    "sortOrder": "desc"
                }
            };
        }
    }

    listBlock["operations"] = Object.assign(listBlock["operations"], {
        "tableHeader": {
            "slot": "rightTop",
            "type": "filter",
            "label": "表头管理",
            "props": {
                "type": "primary",
            },
        },
        "copyRow": {
            "type": "button",
            "label": "复制行",
            "props": {
                "type": "primary",
                "icon": "el-icon-copy"
            },
            "event": "copyRow"
        },
    });

    mergeBlock(matchBlock, listBlock);
    if(!listBlock["operations"].hasOwnProperty("search")){
        listBlock["operations"]["search"] = {
            "slot": "searchs",
            "type": "button",
            "label": "搜索",
            "props": {
                "type": "primary",
                "icon": "el-icon-search"
            },
            "event": "list:1"
        };
    }

    ams.blockConfig["listBlockMap"][block["uniqueKey"]] = listBlock;
    ams.block(block["listBlockName"], listBlock);

    if(listBlock.hasOwnProperty("headerNames")){
        //设置默认表头展示列
        let itemName = "AMS_BLOCK_"+block["listBlockName"];
        if(null==localStorage.getItem(itemName)){
            localStorage.setItem(itemName,"\""+listBlock["headerNames"]+"\"");
        }
    }
}

function mergeBlock(sourceBlock,targetBlock){
    for(let prop in sourceBlock){
        if(!sourceBlock.hasOwnProperty(prop)){
            continue;
        }
        if(!targetBlock.hasOwnProperty(prop)){
            targetBlock[prop] = sourceBlock[prop];
            continue;
        }
        if(typeof(sourceBlock[prop])=="object"){
            mergeBlock(sourceBlock[prop], targetBlock[prop]);
        }else{
            targetBlock[prop] = sourceBlock[prop];
        }
    }
}

==> QuickAMS-1.1.0-sources.jar: static/load/loadListBlock.js <==
function getMatchBlock(block){
    //匹配公共部分
    for(let prop in userBlockMap){
        let tokens = prop.split("|");
        let projectName = tokens[0];
        let daoName = tokens[1];
        let tableName = tokens[2];

        if(projectName===block["projectName"]&&daoName==="common"&&tableName===block["tableName"]){
            return userBlockMap[prop];
        }
    }
    //完全匹配
    for(let prop in userBlockMap){
        let tokens = prop.split("|");
        let projectName = tokens[0];
        let daoName = tokens[1];
        let tableName = tokens[2];

        if(projectName===block["projectName"]&&daoName===block["daoName"]&&tableName===block["tableName"]){
            return userBlockMap[prop];
        }
    }
}

function loadBlock(block){
    let matchBlock = getMatchBlock(block);
    loadResource(block, matchBlock);
    loadListBlock(block, matchBlock);
}

function loadResource(block, matchBlock) {
    let resourceBlock = {
        "key": block["id"],
        "api": {
            "prefix": "/ams/api/"+block["projectName"]+"/"+block["daoName"]+"/"+block["tableName"],
            "list": "/list",
            "create": "/create",
            "update": "/update",
            "delete": "/delete"
        },
        "fields": block["resourceFields"]
    };
    if(null!=matchBlock&&matchBlock.hasOwnProperty("resource")){
        mergeBlock(matchBlock["resource"], resourceBlock);
        delete matchBlock["resource"];
    }
    ams.blockConfig["resourceBlockMap"][block["uniqueKey"]] = resourceBlock;
    ams.resource(block["resourceName"], resourceBlock);
}

function loadListBlock(block, matchBlock){
    let listBlock = {
        "resource": block["resourceName"],
        "type": "list",
        "ctx": "view",
        "props": {
            "empty-text": "暂无记录",
        },
        "sorts": {},
        "expand": {},
        "options": {
            "multipleSelect": true,
        },
        "operations":{

        },
        "actions": {
            initialCondition(){
                let searchFields = Object.keys(this["fields"]);
                for(let i=0;i<searchFields.length;i++){
                    let value = ams.utils.getQueryString(searchFields[i]);
                    if(null!=value&&value!==""){
                        value = decodeURIComponent(value);
                        this["data"]["searchs"][searchFields[i]] = value;
                    }
                }
                if(block["initList"]){
                    this.callAction("list:1");
                }
            },
            copyRow(params) {
                let row = params.$prevReturn;
                setClipBoard(JSON.stringify(row));
                this.$message.success("行数据已复制到剪贴板");
            },
            multipleDelete(params){
                let idFieldName = block["id"];
                let ids = ams.utils.getIdsString(params, idFieldName);
                let data = {};
                data[idFieldName] = "in:"+ids;

                return ams.utils.sendRequest(this, {
                    "method": "POST",
                    "url": "/delete",
                    "data": data,
                    "contentType": "form"
                }, "删除记录完成!");
            }
        }
    };
    listBlock["events"] = {
        "init": "initialCondition"
    };
    listBlock["operations"] = block["operationFields"];

    for(let prop in block["resourceFields"]){
        listBlock["sorts"][prop] = true;
        listBlock["expand"][prop] = true;
        if(prop==="id"){
            listBlock["data"] = {
                "searchs": {
                    "sortField": "id",
                    "sortOrder": "desc"
                }
            };
        }
    }

    listBlock["operations"] = Object.assign(listBlock["operations"], {
        "tableHeader": {
            "slot": "rightTop",
            "type": "filter",
            "label": "表头管理",
            "props": {
                "type": "primary",
            },
        },
        "copyRow": {
            "type": "button",
            "label": "复制行",
            "props": {
                "type": "primary",
                "icon": "el-icon-copy"
            },
            "event": "copyRow"
        },
    });

    mergeBlock(matchBlock, listBlock);
    if(!listBlock["operations"].hasOwnProperty("search")){
        listBlock["operations"]["search"] = {
            "slot": "searchs",
            "type": "button",
            "label": "搜索",
            "props": {
                "type": "primary",
                "icon": "el-icon-search"
            },
            "event": "list:1"
        };
    }

    if(block.hasOwnProperty("operations")){
        let operations = block["operations"];
        for(let i=0;i<operations.length;i++){
            let operation = operations[i];
            if(listBlock["operations"].hasOwnProperty(operation["key"])){
                continue;
            }

            listBlock["operations"][operation["key"]] = {
                "type": "button",
                "label": operation["label"],
                "props": {
                    "type": "primary",
                },
                "event": "confirm:确认"+operation["label"]+"吗? "+operation["key"]
            };
            if(operation.hasOwnProperty("slot")){
                listBlock["operations"][operation["key"]]["slot"] = operation["slot"];
            }
            listBlock["actions"][operation["key"]] = function(params){
                let data = {};
                let fieldNameList = operation["fieldNameList"];
                let row = params.$prevReturn;

                if(null==fieldNameList){
                    //不传递任何参数
                }else if(operation["key"].indexOf("multipleSelect")>=0){
                    if(fieldNameList.length===0){
                        data["list"] = row;
                    }else{
                        data[operations["fieldNameList"][0]+"List"] = ams.utils.getIdList(params, operations["fieldNameList"][0]);
                    }
                }else{
                    if(fieldNameList.length===0){
                        data = row;
                    }else{
                        for(let j=0;j<fieldNameList.length;j++){
                            data[fieldNameList[j]] = row[fieldNameList[j]];
                        }
                    }
                }
                return ams.utils.sendRequest(this,{
                    "method": "POST",
                    "url": "/"+operation["key"],
                    "data": data
                }, operation["label"]+"执行完毕");
            }
        }
    }

    ams.blockConfig["listBlockMap"][block["uniqueKey"]] = listBlock;
    ams.block(block["listBlockName"], listBlock);

    if(listBlock.hasOwnProperty("headerNames")){
        //设置默认表头展示列
        let itemName = "AMS_BLOCK_"+block["listBlockName"];
        if(null==localStorage.getItem(itemName)){
            localStorage.setItem(itemName,"\""+listBlock["headerNames"]+"\"");
        }
    }
}

function mergeBlock(sourceBlock,targetBlock){
    for(let prop in sourceBlock){
        if(!sourceBlock.hasOwnProperty(prop)){
            continue;
        }
        if(!targetBlock.hasOwnProperty(prop)){
            targetBlock[prop] = sourceBlock[prop];
            continue;
        }
        if(typeof(sourceBlock[prop])=="object"){
            mergeBlock(sourceBlock[prop], targetBlock[prop]);
        }else{
            targetBlock[prop] = sourceBlock[prop];
        }
    }
}
